@@ -1,5 +1,5 @@
 package Test::BDD::Cucumber;
-$Test::BDD::Cucumber::VERSION = '0.35';
+$Test::BDD::Cucumber::VERSION = '0.50';
 use strict;
 use warnings;
 1;
@@ -12,23 +12,29 @@ Test::BDD::Cucumber - Feature-complete Cucumber-style testing in Perl
 
 =head1 VERSION
 
-version 0.35
+version 0.50
 
 =head1 DESCRIPTION
 
 A sane and complete Cucumber implementation in Perl
 
+Behaviour of this module is similar to that, but sometimes different from
+the I<real> Cucumber, the plan is to move use the same parser and behaviour
+L<See the logged issue|https://github.com/pjlsergeant/test-bdd-cucumber-perl/issues/73>.
+
 =head1 QUICK LINKS
 
-L<Cucumber on Perl on MetaCPAN|https://metacpan.org/release/Test-BDD-Cucumber>
+See this distribution: L<Cucumber on Perl on MetaCPAN|https://metacpan.org/release/Test-BDD-Cucumber>
 
-=head1 WARNING
+=begin html
 
-Do have a read of the B<Bugs and Missing> section below so you're not surprised
-when things don't work.
+You can talk to the author(s) here: <a
+href="https://gitter.im/pjlsergeant/test-bdd-cucumber-perl"><img
+    src="https://badges.gitter.im/pjlsergeant/test-bdd-cucumber-perl.svg"
+    alt="Chat on Gitter"
+></a>
 
-In almost all cases, where the behaviour of this module is different from
-the I<real> Cucumber, the plan is to move it to be more similar to that.
+=end html
 
 =head1 NEXT STEPS
 
@@ -47,7 +53,8 @@ overview|Test::BDD::Cucumber::Manual::Architecture>.
 
 =head1 TEN SECOND GUIDE TO USING THIS IN YOUR CI ENVIRONMENT
 
-Don't use the command-line tool, L<App::pherkin>. Instead, look at the L<How to integrate with
+Don't use the command-line tool, L<App::pherkin>, for integration in your
+CI environment. Instead, look at the L<How to integrate with
 Test::Builder|Test::BDD::Cucumber::Manual::Integration> document.
 
 =head1 BUGS, MISSING, AND LIMITATIONS
@@ -61,10 +68,6 @@ in the very near future:
 
 =item * Placeholders in pystrings is broken
 
-=item * Explicit Step Outline notation doesn't work (although step outlines are explicitly supported)
-
-=item * Pherkin isn't really fit for purpose yet
-
 =back
 
 =head1 CODE
@@ -75,10 +78,12 @@ On Github, of course: L<https://github.com/pjlsergeant/test-bdd-cucumber-perl>.
 
 Peter Sergeant C<pete@clueball.com>
 
+Erik Huelsmann C<ehuels@gmail.com>
+
 Ben Rodgers C<ben@bdr.org>
 
 =head1 LICENSE
 
-Copyright 2011-2014, Peter Sergeant; Licensed under the same terms as Perl
+Copyright 2011-2016, Peter Sergeant; Licensed under the same terms as Perl
 
 =cut
